Or class

Generate an optional condition.

Inheritance

Constructors

Or(String evaluatedField)
Generate an optional condition.
const

Properties

compare → Compare
The kind of comparison of the evaluatedField to the value. Defaults to Compare.exact. It is the responsibility of the Provider to ignore or interpret the requested comparison.
finalinherited
conditions → List<WhereCondition>?
Nested conditions. Leave unchanged for WhereConditions that do not nest.
finalinherited
evaluatedField → String
The Dart name of the field. For example, myField when querying final String myField.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isRequired → bool
Whether the condition(s) must evaluate to true. Defaults true.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
The value to compare on the evaluatedField.
finalinherited

Methods

contains(dynamic value) → Where
Convenience function to create a Where with Compare.contains.
inherited
doesNotContain(dynamic value) → Where
Convenience function to create a Where with Compare.doesNotContain.
inherited
isBetween(dynamic value1, dynamic value2) → Where
Convenience function to create a Where with Compare.between.
inherited
isExactly(dynamic value) → Where
Convenience function to create a Where with Compare.exact.
inherited
isGreaterThan(dynamic value) → Where
Convenience function to create a Where with Compare.greaterThan.
inherited
isGreaterThanOrEqualTo(dynamic value) → Where
Convenience function to create a Where with Compare.greaterThanOrEqualTo.
inherited
isIn(Iterable values) → Where
Convenience function to create a Where with Compare.inIterable.
inherited
isLessThan(dynamic value) → Where
Convenience function to create a Where with Compare.lessThan.
inherited
isLessThanOrEqualTo(dynamic value) → Where
Convenience function to create a Where with Compare.lessThanOrEqualTo.
inherited
isNot(dynamic value) → Where
Convenience function to create a Where with Compare.notEqual.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serialize to JSON
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited