OrderBy class

Construct directions for a provider to sort its results.

Constructors

OrderBy(String evaluatedField, {bool ascending = true, String? associationField})
Construct directions for a provider to sort its results.
const
OrderBy.asc(String evaluatedField, {String? associationField})
Sort by ascending order (A-Z).
const
OrderBy.desc(String evaluatedField, {String? associationField})
Sort by descending order (Z-A).
const
OrderBy.fromJson(Map<String, dynamic> json)
Construct an OrderBy from a JSON map.
factory

Properties

ascending → bool
Defaults to true.
final
associationField → String?
The Dart name of the field of the association model if the evaluatedField is an association.
final
evaluatedField → String
The Dart name of the field. For example, myField when querying final String myField.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serialize to JSON
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override